@@ -29,16 +29,45 @@ class Queries : public QObject
 public:
     enum QueryType {
         StationSearch = 0,
+        PodcastSearch,
         FavouriteStations,
         RecentlyPlayedStations,
         Genres,
+        PodcastGenres,
         Countries,
+        PodcastCountries,
         Languages,
-        Recordings,
+        PodcastLanguages,
+        Names,
+        PodcastNames,
         Unknown
     };
 };
 
+class Services : public QObject
+{
+    Q_OBJECT
+    Q_ENUMS(RadioService)
+
+public:
+    enum RadioService {
+        NoService = 0,
+        TuneIn
+    };
+};
+
+class Stations : public QObject
+{
+    Q_OBJECT
+    Q_ENUMS(StationType)
+
+public:
+    enum StationType {
+        Radio = 0,
+        Podcast
+    };
+};
+
 class ScreenOrientation : public QObject
 {
     Q_OBJECT
