@@ -23,7 +23,13 @@ HomescreenModel::HomescreenModel(QObject *parent) :
                      << tr("Stations by country")
                      << tr("Stations by language")
                      << tr("Recently played stations")
-                     << tr("Favourite stations"), parent)
+                     << tr("Favourite stations")
+#ifdef TUNE_IN
+                     << tr("Podcasts")
+                     << tr("TuneIn"), parent)
+#else
+                     << tr("Podcasts"), parent)
+#endif
 {
     m_roleNames[Qt::DisplayRole] = "name";
 #if QT_VERSION < 0x050000
