@@ -10,10 +10,15 @@ class NetworkAccessManager : public QNetworkAccessManager
 public:
     explicit NetworkAccessManager(QObject *parent = 0);
 
+    static NetworkAccessManager* instance();
+
 private slots:
     void onSSLErrors(QNetworkReply *reply, const QList<QSslError> &errors);
 
     void onProxyAuthenticationRequired(const QNetworkProxy &proxy, QAuthenticator *authenticator);
+
+private:
+    static NetworkAccessManager *self;
 };
 
 #endif // NETWORKACCESSMANAGER_H
