@@ -314,3 +314,37 @@ NetworkProxyTypeModel::NetworkProxyTypeModel(QObject *parent) :
 
     emit countChanged(this->rowCount());
 }
+
+MediaPlayerModel::MediaPlayerModel(QObject *parent) :
+    SelectionModel(parent)
+{
+    this->addItem(tr("cuteRadio"), "cuteradio");
+#ifdef Q_OS_UNIX
+    this->addItem(tr("Custom command"), "other");
+
+    QFileInfo info("/usr/bin/kmplayer");
+
+    if (info.exists()) {
+        this->addItem("KMPlayer", "kmplayer");
+    }
+    else {
+        info.setFile("/opt/kmplayer/bin/kmplayer");
+
+        if (info.exists()) {
+            this->addItem("KMPlayer", "kmplayer");
+        }
+    }
+#endif
+    this->addItem(tr("Media Player"), "mediaplayer");
+
+    emit countChanged(this->rowCount());
+}
+
+StationTypeModel::StationTypeModel(QObject *parent) :
+    SelectionModel(parent)
+{
+    this->addItem(tr("Stations"), Stations::Radio);
+    this->addItem(tr("Podcasts"), Stations::Podcast);
+
+    emit countChanged(this->rowCount());
+}
