@@ -110,4 +110,34 @@ signals:
     void countChanged(int count);
 };
 
+class MediaPlayerModel : public SelectionModel
+{
+    Q_OBJECT
+
+    Q_PROPERTY(int count
+               READ rowCount
+               NOTIFY countChanged)
+
+public:
+    explicit MediaPlayerModel(QObject *parent = 0);
+
+signals:
+    void countChanged(int count);
+};
+
+class StationTypeModel : public SelectionModel
+{
+    Q_OBJECT
+
+    Q_PROPERTY(int count
+               READ rowCount
+               NOTIFY countChanged)
+
+public:
+    explicit StationTypeModel(QObject *parent = 0);
+
+signals:
+    void countChanged(int count);
+};
+
 #endif // SELECTIONMODELS_H
