@@ -34,6 +34,17 @@ Settings* Settings::instance() {
     return !self ? new Settings : self;
 }
 
+Stations::StationType Settings::searchType() const {
+    return static_cast<Stations::StationType>(this->value("Media/searchType", Stations::Radio).toInt());
+}
+
+void Settings::setSearchType(Stations::StationType type) {
+    if (type != this->searchType()) {
+        this->setValue("Media/searchType", Stations::StationType(type));
+        emit searchTypeChanged(type);
+    }
+}
+
 ScreenOrientation::Orientation Settings::screenOrientation() const {
     return static_cast<ScreenOrientation::Orientation>(this->value("Other/screenOrientation", ScreenOrientation::Automatic).toInt());
 }
@@ -56,6 +67,30 @@ void Settings::setSleepTimerDuration(int duration) {
     }
 }
 
+QString Settings::mediaPlayer() const {
+    return this->value("Media/mediaPlayer", "cuteradio").toString();
+}
+
+void Settings::setMediaPlayer(const QString &player) {
+    if (player != this->mediaPlayer()) {
+        this->setValue("Media/mediaPlayer", player);
+        emit mediaPlayerChanged(player);
+    }
+}
+
+#ifdef Q_OS_UNIX
+QString Settings::mediaPlayerCommand() const {
+    return this->value("Media/mediaPlayerCommand").toString();
+}
+
+void Settings::setMediaPlayerCommand(const QString &command) {
+    if (command != this->mediaPlayerCommand()) {
+        this->setValue("Media/mediaPlayerCommand", command);
+        emit mediaPlayerCommandChanged(command);
+    }
+}
+#endif
+
 QString Settings::language() const {
     return this->value("Other/language", "en").toString();
 }
