@@ -25,6 +25,10 @@ class Settings : public QSettings
 {
     Q_OBJECT
 
+    Q_PROPERTY(Stations::StationType searchType
+               READ searchType
+               WRITE setSearchType
+               NOTIFY searchTypeChanged)
     Q_PROPERTY(ScreenOrientation::Orientation screenOrientation
                READ screenOrientation
                WRITE setScreenOrientation
@@ -33,6 +37,16 @@ class Settings : public QSettings
                READ sleepTimerDuration
                WRITE setSleepTimerDuration
                NOTIFY sleepTimerDurationChanged)
+    Q_PROPERTY(QString mediaPlayer
+               READ mediaPlayer
+               WRITE setMediaPlayer
+               NOTIFY mediaPlayerChanged)
+#ifdef Q_OS_UNIX
+    Q_PROPERTY(QString mediaPlayerCommand
+               READ mediaPlayerCommand
+               WRITE setMediaPlayerCommand
+               NOTIFY mediaPlayerCommandChanged)
+#endif
     Q_PROPERTY(QString language
                READ language
                WRITE setLanguage
@@ -86,12 +100,21 @@ public:
 
     static Settings* instance();
 
+    Stations::StationType searchType() const;
+    void setSearchType(Stations::StationType type);
+
     ScreenOrientation::Orientation screenOrientation() const;
     void setScreenOrientation(ScreenOrientation::Orientation orientation);
 
     int sleepTimerDuration() const;
     void setSleepTimerDuration(int duration);
 
+    QString mediaPlayer() const;
+    void setMediaPlayer(const QString &player);
+
+    QString mediaPlayerCommand() const;
+    void setMediaPlayerCommand(const QString &command);
+
     QString language() const;
     void setLanguage(const QString &language);
 
@@ -129,11 +152,16 @@ public slots:
     void setNetworkProxy();
 
 signals:
+    void searchTypeChanged(Stations::StationType type);
+
     void screenOrientationChanged(ScreenOrientation::Orientation orientation);
 
     void sleepTimerEnabledChanged(bool enabled);
     void sleepTimerDurationChanged(int duration);
 
+    void mediaPlayerChanged(const QString &player);
+    void mediaPlayerCommandChanged(const QString &command);
+
     void languageChanged(const QString &language);
 
     void networkProxyEnabledChanged(bool enabled);
