@@ -24,26 +24,75 @@
 #include "utils.h"
 #include "networkaccessmanager.h"
 
-#define MAX_RETRIES 2
+StreamExtractor* StreamExtractor::self = 0;
+
+static const int MAX_RETRIES = 8;
 
 StreamExtractor::StreamExtractor(QObject *parent) :
     QObject(parent),
-    m_nam(new NetworkAccessManager(this)),
-    m_retries(MAX_RETRIES)
-{
-}
-
-StreamExtractor::StreamExtractor(QNetworkAccessManager *manager, QObject *parent) :
-    QObject(parent),
-    m_nam(!manager ? new NetworkAccessManager(this) : manager),
-    m_retries(MAX_RETRIES)
+    m_retries(0),
+    m_busy(false),
+    m_canceled(false)
 {
+    if (!self) {
+        self = this;
+    }
 }
 
 StreamExtractor::~StreamExtractor() {}
 
-void StreamExtractor::cancelCurrentOperation() {
-    emit currentOperationCancelled();
+StreamExtractor* StreamExtractor::instance() {
+    return !self ? new StreamExtractor : self;
+}
+
+static QString getUrlFromASXFile(const QString &response) {
+    QDomDocument doc;
+    doc.setContent(response.toLower());
+    QDomNode node = doc.documentElement().namedItem("entry");
+
+    return node.firstChildElement("ref").attribute("href");
+}
+
+static QString getUrlFromPLSFile(const QString &response) {
+    return response.section(QRegExp("File\\d=", Qt::CaseInsensitive), 1, 1).section(QRegExp("\\s"), 0, 0);
+}
+
+static QString getUrlFromM3UFile(const QString &response) {
+    QRegExp re("http(s|)://\\S+", Qt::CaseInsensitive);
+
+    return re.indexIn(response) >= 0 ? re.cap() : QString();
+}
+
+static QString getUrlFromSMILFile(const QString &response) {
+    QDomDocument doc;
+    doc.setContent(response.toLower());
+    QDomNode node = doc.documentElement().namedItem("body");
+
+    return node.firstChildElement("audio").attribute("src");
+}
+
+static QString getUrlFromUnknownFile(const QString &response) {
+    QRegExp re("http(s|)://[^\\s\"'<>]+", Qt::CaseInsensitive);
+
+    return re.indexIn(response) >= 0 ? re.cap() : QString();
+}
+
+static QString getUrlFromPlaylistFile(const QString &response, const QString &format) {
+    if (format == "asx") {
+        return getUrlFromASXFile(response);
+    }
+    else if (format == "pls") {
+        return getUrlFromPLSFile(response);
+    }
+    else if (format == "m3u") {
+        return getUrlFromM3UFile(response);
+    }
+    else if (format == "smil") {
+        return getUrlFromSMILFile(response);
+    }
+    else {
+        return getUrlFromUnknownFile(response);
+    }
 }
 
 int StreamExtractor::retries() const {
@@ -54,25 +103,60 @@ void StreamExtractor::setRetries(int retries) {
     m_retries = retries;
 }
 
+bool StreamExtractor::busy() const {
+    return m_busy;
+}
+
+void StreamExtractor::setBusy(bool isBusy, const QString &message, int numberOfOperations) {
+    if (isBusy != this->busy()) {
+        m_busy = isBusy;
+        emit busyChanged(isBusy);
+    }
+
+    if (isBusy) {
+        this->setCanceled(false);
+        emit busy(message, numberOfOperations);
+    }
+    else if (!this->canceled()) {
+        emit busyProgressChanged(numberOfOperations);
+    }
+}
+
+bool StreamExtractor::canceled() const {
+    return m_canceled;
+}
+
+void StreamExtractor::setCanceled(bool canceled) {
+    m_canceled = canceled;
+}
+
+void StreamExtractor::cancelCurrentOperation() {
+    this->setCanceled(true);
+    this->setBusy(false);
+    emit currentOperationCanceled();
+}
+
 void StreamExtractor::getStreamUrl(const QUrl &url) {
-    this->setRetries(MAX_RETRIES);
+    this->setBusy(true, tr("Retrieving stream URL"));
+    this->setRetries(0);
     QNetworkRequest request(url);
-    QNetworkReply *reply = m_nam->get(request);
+    QNetworkReply *reply = NetworkAccessManager::instance()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(parseResponse()));
-    this->connect(this, SIGNAL(currentOperationCancelled()), reply, SLOT(deleteLater()));
+    this->connect(this, SIGNAL(currentOperationCanceled()), reply, SLOT(deleteLater()));
 }
 
 void StreamExtractor::retry(const QUrl &url) {
     QNetworkRequest request(url);
-    QNetworkReply *reply = m_nam->get(request);
+    QNetworkReply *reply = NetworkAccessManager::instance()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(parseResponse()));
-    this->connect(this, SIGNAL(currentOperationCancelled()), reply, SLOT(deleteLater()));
+    this->connect(this, SIGNAL(currentOperationCanceled()), reply, SLOT(deleteLater()));
 }
 
 void StreamExtractor::parseResponse() {
     QNetworkReply *reply = qobject_cast<QNetworkReply*>(this->sender());
 
     if (!reply) {
+        this->setBusy(false);
         emit error(tr("Network error"));
         return;
     }
@@ -84,6 +168,7 @@ void StreamExtractor::parseResponse() {
         reply->deleteLater();
         return;
     default:
+        this->setBusy(false);
         emit error(reply->errorString());
         reply->deleteLater();
         return;
@@ -92,33 +177,37 @@ void StreamExtractor::parseResponse() {
     QUrl redirect = reply->attribute(QNetworkRequest::RedirectionTargetAttribute).toUrl();
 
     if (!redirect.isEmpty()) {
-        if (this->retries()) {
-            this->setRetries(this->retries() - 1);
+        if (this->retries() < MAX_RETRIES) {
+            this->setRetries(this->retries() + 1);
             this->retry(redirect);
         }
         else {
+            this->setBusy(false);
             emit error(tr("Cannot find stream url"));
         }
     }
     else {
         QString response(reply->readAll());
         QString format = reply->url().toString().section('.', -1).toLower();
-        QUrl url(this->getUrlFromPlaylistFile(response, format));
+        QUrl url(getUrlFromPlaylistFile(response, format));
 
         if (url.isEmpty()) {
+            this->setBusy(false);
             emit error(tr("Cannot find stream url"));
         }
         else {
             if (Utils::urlIsPlaylist(url)) {
-                if (this->retries()) {
-                    this->setRetries(this->retries() - 1);
+                if (this->retries() < MAX_RETRIES) {
+                    this->setRetries(this->retries() + 1);
                     this->retry(url);
                 }
                 else {
+                    this->setBusy(false);
                     emit error(tr("Cannot find stream url"));
                 }
             }
             else {
+                this->setBusy(false);
                 emit gotStreamUrl(url);
             }
         }
@@ -126,53 +215,3 @@ void StreamExtractor::parseResponse() {
 
     reply->deleteLater();
 }
-
-QString StreamExtractor::getUrlFromPlaylistFile(const QString &response, const QString &format) {
-    if (format == "asx") {
-        return this->getUrlFromASXFile(response);
-    }
-    else if (format == "pls") {
-        return this->getUrlFromPLSFile(response);
-    }
-    else if (format == "m3u") {
-        return this->getUrlFromM3UFile(response);
-    }
-    else if (format == "smil") {
-        return this->getUrlFromSMILFile(response);
-    }
-    else {
-        return this->getUrlFromUnknownFile(response);
-    }
-}
-
-QString StreamExtractor::getUrlFromASXFile(const QString &response) {
-    QDomDocument doc;
-    doc.setContent(response.toLower());
-    QDomNode node = doc.documentElement().namedItem("entry");
-
-    return node.firstChildElement("ref").attribute("href");
-}
-
-QString StreamExtractor::getUrlFromPLSFile(const QString &response) {
-    return response.section(QRegExp("File\\d=", Qt::CaseInsensitive), 1, 1).section(QRegExp("\\s"), 0, 0);
-}
-
-QString StreamExtractor::getUrlFromM3UFile(const QString &response) {
-    QRegExp re("http(s|)://\\S+", Qt::CaseInsensitive);
-
-    return re.indexIn(response) >= 0 ? re.cap() : QString();
-}
-
-QString StreamExtractor::getUrlFromSMILFile(const QString &response) {
-    QDomDocument doc;
-    doc.setContent(response.toLower());
-    QDomNode node = doc.documentElement().namedItem("body");
-
-    return node.firstChildElement("audio").attribute("src");
-}
-
-QString StreamExtractor::getUrlFromUnknownFile(const QString &response) {
-    QRegExp re("http(s|)://[^\\s\"'<>]+", Qt::CaseInsensitive);
-
-    return re.indexIn(response) >= 0 ? re.cap() : QString();
-}
