@@ -21,7 +21,6 @@
 #include <QObject>
 
 class QUrl;
-class QNetworkAccessManager;
 
 class StreamExtractor : public QObject
 {
@@ -29,37 +28,47 @@ class StreamExtractor : public QObject
 
 public:
     explicit StreamExtractor(QObject *parent = 0);
-    explicit StreamExtractor(QNetworkAccessManager *manager, QObject *parent = 0);
     ~StreamExtractor();
+
+    static StreamExtractor* instance();
+
+    bool busy() const;
+
+    bool canceled() const;
     
 public slots:
     void getStreamUrl(const QUrl &url);
+
     void cancelCurrentOperation();
 
 private:
     int retries() const;
     void setRetries(int retries);
 
-    void retry(const QUrl &url);
+    void setBusy(bool isBusy, const QString &message = QString(), int numberOfOperations = 1);
 
-    QString getUrlFromPlaylistFile(const QString &response, const QString &format);
-    QString getUrlFromASXFile(const QString &response);
-    QString getUrlFromPLSFile(const QString &response);
-    QString getUrlFromM3UFile(const QString &response);
-    QString getUrlFromSMILFile(const QString &response);
-    QString getUrlFromUnknownFile(const QString &response);
+    void setCanceled(bool canceled);
+
+    void retry(const QUrl &url);
 
 private slots:
     void parseResponse();
 
 signals:
     void gotStreamUrl(const QUrl &url);
-    void currentOperationCancelled();
+    void currentOperationCanceled();
+    void busy(const QString &message, int numberOfOperations);
+    void busyProgressChanged(int progress);
+    void busyChanged(bool isBusy);
     void error(const QString &errorString);
 
 private:
-    QNetworkAccessManager *m_nam;
+    static StreamExtractor *self;
+
     int m_retries;
+
+    bool m_busy;
+    bool m_canceled;
 };
 
 #endif // STREAMEXTRACTOR_H
