@@ -16,14 +16,14 @@
  */
 
 #include <QStringListModel>
-#include <QSettings>
 #include "stringlistmodel.h"
+#include "settings.h"
 
 StringListModel::StringListModel(QObject *parent) :
     QSortFilterProxyModel(parent),
     m_model(new QStringListModel(this))
   #if (defined QML_USER_INTERFACE) && (!defined Q_WS_MAEMO_5)
-  ,m_highlight(QSettings().value("Appearance/activeColor", "#0881cb").toString())
+  ,m_highlight(Settings::instance()->activeColor())
   #endif
 {
     m_roleNames[NameRole] = "name";
