@@ -19,6 +19,14 @@
 #include <QFileInfo>
 #include <QFile>
 #include <QStringList>
+#include <qplatformdefs.h>
+#ifdef Q_OS_SYMBIAN
+#include <QCoreApplication>
+#elif QT_VERSION >= 0x050000
+#include <QStandardPaths>
+#else
+#include <QDesktopServices>
+#endif
 
 Utils::Utils(QObject *parent) :
     QObject(parent)
@@ -130,7 +138,7 @@ QString Utils::httpErrorString(int errorCode) {
 bool Utils::urlIsPlaylist(const QUrl &url) {
     QString urlString = url.toString().toLower();
 
-    return (urlString.endsWith(".pls")) || (urlString.endsWith(".asx")) || (urlString.endsWith(".m3u") || (urlString.endsWith(".smil")));
+    return (url.host() == "opml.radiotime.com") || (urlString.endsWith(".pls")) || (urlString.endsWith(".asx")) || (urlString.endsWith(".m3u")) || (urlString.endsWith(".smil"));
 }
 
 QString Utils::capitalise(const QString &string) {
@@ -161,5 +169,17 @@ void Utils::log(const QString &filePath, const QByteArray &message) {
 }
 
 QString Utils::versionNumber() {
-    return QString("0.1.2");
+    return QString("0.2.0");
+}
+
+QString Utils::logoPath() {
+#ifdef Q_OS_SYMBIAN
+    return QCoreApplication::applicationDirPath() + "/.logos/";
+#elif (defined MEEGO_EDITION_HARMATTAN) || (defined Q_WS_MAEMO_5)
+    return QString("/home/user/cuteRadio/.logos/");
+#elif QT_VERSION >= 0x050000
+    return QStandardPaths::writeableLocation(QStandardPaths::HomeLocation) + "/cuteRadio/.logos/";
+#else
+    return QDesktopServices::storageLocation(QDesktopServices::HomeLocation) + "/cuteRadio/.logos/";
+#endif
 }
