@@ -22,15 +22,31 @@
 #include <QDeclarativeContext>
 #include <qdeclarative.h>
 #include <QGLWidget>
+#include "launcher.h"
 #include "../base/homescreenmodel.h"
 #include "../base/database.h"
 #include "../base/stationfilterlistmodel.h"
+#include "../base/podcastfilterlistmodel.h"
+#include "../base/podcastepisodefilterlistmodel.h"
 #include "../base/pairlistmodel.h"
 #include "../base/searchlistmodel.h"
 #include "../base/selectionmodels.h"
 #include "../base/settings.h"
 #include "../base/utils.h"
+#include "../base/logodownloader.h"
+#include "../base/streamextractor.h"
+#include "../base/podcast.h"
+#ifdef MOBILITY_PLAYER
+#include "../mediaplayer/mobility/mediaplayer.h"
+#else
 #include "../mediaplayer/phonon/mediaplayer.h"
+#endif
+#include "../tunein/tuneinhomescreenmodel.h"
+#include "../tunein/tuneinstationfilterlistmodel.h"
+#include "../tunein/tuneinpairlistmodel.h"
+#include "../tunein/tuneinpodcastfilterlistmodel.h"
+#include "../tunein/tuneinpodcastepisodefilterlistmodel.h"
+#include "../tunein/tuneinstation.h"
 
 Q_DECL_EXPORT int main(int argc, char *argv[])
 {
@@ -45,21 +61,38 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 
     qmlRegisterType<HomescreenModel>("com.cuteradio.models", 1, 0, "HomescreenModel");
     qmlRegisterType<StationFilterListModel>("com.cuteradio.models", 1, 0, "StationListModel");
+    qmlRegisterType<PodcastFilterListModel>("com.cuteradio.models", 1, 0, "PodcastListModel");
+    qmlRegisterType<PodcastEpisodeFilterListModel>("com.cuteradio.models", 1, 0, "PodcastEpisodeListModel");
     qmlRegisterType<PairListModel>("com.cuteradio.models", 1, 0, "PairListModel");
+    qmlRegisterType<TuneInHomescreenModel>("com.cuteradio.models", 1, 0, "TuneInHomescreenModel");
+    qmlRegisterType<TuneInStationFilterListModel>("com.cuteradio.models", 1, 0, "TuneInStationListModel");
+    qmlRegisterType<TuneInPairListModel>("com.cuteradio.models", 1, 0, "TuneInPairListModel");
+    qmlRegisterType<TuneInPodcastFilterListModel>("com.cuteradio.models", 1, 0, "TuneInPodcastListModel");
+    qmlRegisterType<TuneInPodcastEpisodeFilterListModel>("com.cuteradio.models", 1, 0, "TuneInPodcastEpisodeListModel");
     qmlRegisterType<ScreenOrientationModel>("com.cuteradio.models", 1, 0, "ScreenOrientationModel");
     qmlRegisterType<LanguageModel>("com.cuteradio.models", 1, 0, "LanguageModel");
+    qmlRegisterType<MediaPlayerModel>("com.cuteradio.models", 1, 0, "MediaPlayerModel");
+    qmlRegisterType<StationTypeModel>("com.cuteradio.models", 1, 0, "StationTypeModel");
     qmlRegisterType<ActiveColorModel>("com.cuteradio.models", 1, 0, "ActiveColorModel");
+    qmlRegisterType<NetworkProxyTypeModel>("com.cuteradio.models", 1, 0, "NetworkProxyTypeModel");
     qmlRegisterType<Station>("com.cuteradio.items", 1, 0, "Station");
+    qmlRegisterType<Podcast>("com.cuteradio.items", 1, 0, "Podcast");
+    qmlRegisterType<TuneInStation>("com.cuteradio.items", 1, 0, "TuneInStation");
+    qmlRegisterType<LogoDownloader>("com.cuteradio.items", 1, 0, "LogoDownloader");
 
     qmlRegisterUncreatableType<ScreenOrientation>("com.cuteradio.enums", 1, 0, "ScreenOrientation", "Y U create enum?");
     qmlRegisterUncreatableType<Queries>("com.cuteradio.enums", 1, 0, "Queries", "Y U create enum?");
     qmlRegisterUncreatableType<PlaybackMode>("com.cuteradio.enums", 1, 0, "PlaybackMode", "Y U create enum?");
+    qmlRegisterUncreatableType<Services>("com.cuteradio.enums", 1, 0, "Services", "Y U create enum?");
+    qmlRegisterUncreatableType<Stations>("com.cuteradio.enums", 1, 0, "Stations", "Y U create enum?");
 
     Settings settings;
     Database database;
     Utils utils;
+    StreamExtractor extractor;
     MediaPlayer player;
     SearchListModel searchModel;
+    Launcher launcher;
 
     if (!settings.language().isEmpty()) {
         QTranslator translator;
@@ -75,11 +108,14 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     context->setContextProperty("Database", &database);
     context->setContextProperty("MediaPlayer", &player);
     context->setContextProperty("SearchModel", &searchModel);
+    context->setContextProperty("StreamExtractor", &extractor);
+    context->setContextProperty("Launcher", &launcher);
 
     view.data()->setViewport(new QGLWidget);
     view.data()->setSource(QUrl("qrc:/main.qml"));
     view.data()->showFullScreen();
 
+    QObject::connect(&extractor, SIGNAL(gotStreamUrl(QUrl)), &launcher, SLOT(launch(QUrl)));
     QObject::connect(view.data()->engine(), SIGNAL(quit()), app.data(), SLOT(quit()));
 
     return app.data()->exec();
