@@ -25,11 +25,14 @@
 #include "scrollarea.h"
 #include "../base/station.h"
 #include "../base/database.h"
+#include "../base/logodownloader.h"
+#include "../base/utils.h"
 
 AddStationDialog::AddStationDialog(QWidget *parent) :
     AbstractDialog(parent),
     m_station(0),
     m_titleEdit(new QLineEdit(this)),
+    m_logoEdit(new QLineEdit(this)),
     m_genreEdit(new QLineEdit(this)),
     m_countryEdit(new QLineEdit(this)),
     m_languageEdit(new QLineEdit(this)),
@@ -49,6 +52,8 @@ AddStationDialog::AddStationDialog(QWidget *parent) :
     vbox->addWidget(m_titleEdit);
     vbox->addWidget(new QLabel(tr("Description"), this));
     vbox->addWidget(m_descriptionEdit);
+    vbox->addWidget(new QLabel(tr("Logo"), this));
+    vbox->addWidget(m_logoEdit);
     vbox->addWidget(new QLabel(tr("Genre"), this));
     vbox->addWidget(m_genreEdit);
     vbox->addWidget(new QLabel(tr("Country"), this));
@@ -77,6 +82,7 @@ AddStationDialog::AddStationDialog(Station *station, QWidget *parent) :
     AbstractDialog(parent),
     m_station(station),
     m_titleEdit(new QLineEdit(station->title(), this)),
+    m_logoEdit(new QLineEdit(station->logo().toString(), this)),
     m_genreEdit(new QLineEdit(station->genre(), this)),
     m_countryEdit(new QLineEdit(station->country(), this)),
     m_languageEdit(new QLineEdit(station->language(), this)),
@@ -96,6 +102,8 @@ AddStationDialog::AddStationDialog(Station *station, QWidget *parent) :
     vbox->addWidget(m_titleEdit);
     vbox->addWidget(new QLabel(tr("Description"), this));
     vbox->addWidget(m_descriptionEdit);
+    vbox->addWidget(new QLabel(tr("Logo"), this));
+    vbox->addWidget(m_logoEdit);
     vbox->addWidget(new QLabel(tr("Genre"), this));
     vbox->addWidget(m_genreEdit);
     vbox->addWidget(new QLabel(tr("Country"), this));
@@ -159,22 +167,63 @@ void AddStationDialog::onSourceChanged(const QString &source) {
 }
 
 void AddStationDialog::addStation() {
-    Database::asyncAddStation(m_titleEdit->text(),
-                              m_descriptionEdit->toPlainText(),
-                              m_genreEdit->text(),
-                              m_countryEdit->text(),
-                              m_languageEdit->text(),
-                              m_sourceEdit->text(),
-                              m_favouriteCheckBox->isChecked());
+    if (!m_logoEdit->text().startsWith("http")) {
+        Database::asyncAddStation(m_titleEdit->text(),
+                                  m_descriptionEdit->toPlainText(),
+                                  QUrl(m_logoEdit->text()),
+                                  m_genreEdit->text(),
+                                  m_countryEdit->text(),
+                                  m_languageEdit->text(),
+                                  m_sourceEdit->text(),
+                                  m_favouriteCheckBox->isChecked());
 
-    this->accept();
+        this->accept();
+    }
+    else {
+        this->toggleBusy(true);
+
+        LogoDownloader *downloader = new LogoDownloader(QUrl(m_logoEdit->text()), QString("%1%2.%3").arg(Utils::logoPath()).arg(m_titleEdit->text()).arg(m_logoEdit->text().section('.', -1)), this);
+        this->connect(downloader, SIGNAL(finished(LogoDownloader*)), this, SLOT(onLogoDownloaderFinished(LogoDownloader*)));
+        downloader->start();
+    }
 }
 
 void AddStationDialog::editStation() {
+    if (m_station) {
+        if (!m_logoEdit->text().startsWith("http")) {
+            QVariantMap properties;
+            properties["title"] = m_titleEdit->text();
+            properties["description"] = m_descriptionEdit->toPlainText();
+            properties["logo"] = m_logoEdit->text();
+            properties["genre"] = m_genreEdit->text();
+            properties["country"] = m_countryEdit->text();
+            properties["language"] = m_languageEdit->text();
+            properties["source"] = m_sourceEdit->text();
+            properties["favourite"] = m_favouriteCheckBox->isChecked() ? 1 : 0;
+
+            Database::asyncUpdateStation(m_station->id(), properties);
+
+            this->accept();
+        }
+        else {
+            this->toggleBusy(true);
+
+            LogoDownloader *downloader = new LogoDownloader(QUrl(m_logoEdit->text()), QString("%1%2.%3").arg(Utils::logoPath()).arg(m_station->id()).arg(m_logoEdit->text().section('.', -1)), this);
+            this->connect(downloader, SIGNAL(finished(LogoDownloader*)), this, SLOT(onLogoDownloaderFinished(LogoDownloader*)));
+            downloader->start();
+        }
+    }
+    else {
+        this->reject();
+    }
+}
+
+void AddStationDialog::onLogoDownloaderFinished(LogoDownloader *downloader) {
     if (m_station) {
         QVariantMap properties;
         properties["title"] = m_titleEdit->text();
         properties["description"] = m_descriptionEdit->toPlainText();
+        properties["logo"] = QUrl(downloader->localPath());
         properties["genre"] = m_genreEdit->text();
         properties["country"] = m_countryEdit->text();
         properties["language"] = m_languageEdit->text();
@@ -182,10 +231,18 @@ void AddStationDialog::editStation() {
         properties["favourite"] = m_favouriteCheckBox->isChecked() ? 1 : 0;
 
         Database::asyncUpdateStation(m_station->id(), properties);
-
-        this->accept();
     }
     else {
-        this->reject();
+        Database::asyncAddStation(m_titleEdit->text(),
+                                  m_descriptionEdit->toPlainText(),
+                                  QUrl(downloader->localPath()),
+                                  m_genreEdit->text(),
+                                  m_countryEdit->text(),
+                                  m_languageEdit->text(),
+                                  m_sourceEdit->text(),
+                                  m_favouriteCheckBox->isChecked());
     }
+
+    this->toggleBusy(false);
+    this->accept();
 }
