@@ -18,10 +18,17 @@
 #include <QApplication>
 #include <QTranslator>
 #include "mainwindow.h"
+#include "launcher.h"
 #include "../base/database.h"
 #include "../base/settings.h"
 #include "../base/utils.h"
+#include "../base/streamextractor.h"
+#include "../thumbnailcache/thumbnailcache.h"
+#ifdef MOBILITY_PLAYER
+#include "../mediaplayer/mobility/mediaplayer.h"
+#else
 #include "../mediaplayer/phonon/mediaplayer.h"
+#endif
 
 int main(int argc, char *argv[]) {
     QApplication app(argc, argv);
@@ -35,7 +42,10 @@ int main(int argc, char *argv[]) {
     Settings settings;
     Database database;
     Utils utils;
+    StreamExtractor extractor;
     MediaPlayer player;
+    Launcher launcher;
+    ThumbnailCache cache;
 
     if (!settings.language().isEmpty()) {
         QTranslator translator;
@@ -48,5 +58,7 @@ int main(int argc, char *argv[]) {
     MainWindow window;
     window.show();
 
+    QObject::connect(&extractor, SIGNAL(gotStreamUrl(QUrl)), &launcher, SLOT(launch(QUrl)));
+
     return app.exec();
 }
