@@ -22,15 +22,22 @@
 #include <QMessageBox>
 #include "stationinfowindow.h"
 #include "separatorlabel.h"
+#include "logolabel.h"
 #include "listview.h"
-#include "nowplayingwindow.h"
 #include "nowplayingbutton.h"
 #include "scrollarea.h"
 #include "addstationdialog.h"
+#include "launcher.h"
 #include "../base/utils.h"
 #include "../base/database.h"
 #include "../base/station.h"
+#include "../base/settings.h"
+#include "../base/streamextractor.h"
+#ifdef MOBILITY_PLAYER
+#include "../mediaplayer/mobility/mediaplayer.h"
+#else
 #include "../mediaplayer/phonon/mediaplayer.h"
+#endif
 
 StationInfoWindow::StationInfoWindow(Station *station, QWidget *parent) :
     StackedWindow(parent),
@@ -45,6 +52,7 @@ StationInfoWindow::StationInfoWindow(Station *station, QWidget *parent) :
     m_languageLabel(new QLabel(this)),
     m_sourceLabel(new QLabel(this)),
     m_lastPlayedLabel(new QLabel(this)),
+    m_logoLabel(new LogoLabel(this)),
     m_scrollArea(new ScrollArea(this))
 {
     this->setWindowTitle(m_station->title());
@@ -57,8 +65,11 @@ StationInfoWindow::StationInfoWindow(Station *station, QWidget *parent) :
     m_sourceLabel->setWordWrap(true);
     m_lastPlayedLabel->setWordWrap(true);
 
+    m_logoLabel->setFixedSize(124, 124);
+
     QWidget *scrollWidget = new QWidget(m_scrollArea);
     QVBoxLayout *vbox = new QVBoxLayout(scrollWidget);
+    vbox->addWidget(m_logoLabel);
     vbox->addWidget(m_descriptionLabel);
     vbox->addWidget(new SeparatorLabel(tr("Properties"), this));
     vbox->addWidget(m_genreLabel);
@@ -73,10 +84,12 @@ StationInfoWindow::StationInfoWindow(Station *station, QWidget *parent) :
     m_scrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     m_scrollArea->setMonitorScrolling(true);
 
+    this->connect(m_logoLabel, SIGNAL(clicked()), this, SLOT(playStation()));
     this->connect(m_scrollArea, SIGNAL(scrollingStarted()), NowPlayingButton::instance(), SLOT(hide()));
     this->connect(m_scrollArea, SIGNAL(scrollingStopped()), NowPlayingButton::instance(), SLOT(poke()));
     this->connect(m_station, SIGNAL(titleChanged(QString)), this, SLOT(onTitleChanged(QString)));
     this->connect(m_station, SIGNAL(descriptionChanged(QString)), this, SLOT(onDescriptionChanged(QString)));
+    this->connect(m_station, SIGNAL(logoChanged(QUrl)), this, SLOT(onLogoChanged(QUrl)));
     this->connect(m_station, SIGNAL(genreChanged(QString)), this, SLOT(onGenreChanged(QString)));
     this->connect(m_station, SIGNAL(countryChanged(QString)), this, SLOT(onCountryChanged(QString)));
     this->connect(m_station, SIGNAL(languageChanged(QString)), this, SLOT(onLanguageChanged(QString)));
@@ -86,6 +99,7 @@ StationInfoWindow::StationInfoWindow(Station *station, QWidget *parent) :
     this->connect(MediaPlayer::instance(), SIGNAL(currentStationChanged(Station*)), this, SLOT(onCurrentStationChanged(Station*)));
 
     this->onDescriptionChanged(m_station->description());
+    this->onLogoChanged(m_station->logo());
     this->onGenreChanged(m_station->genre());
     this->onCountryChanged(m_station->country());
     this->onLanguageChanged(m_station->language());
@@ -95,7 +109,15 @@ StationInfoWindow::StationInfoWindow(Station *station, QWidget *parent) :
 }
 
 void StationInfoWindow::playStation() {
-    MediaPlayer::instance()->play(m_station);
+    if (Settings::instance()->mediaPlayer() == "cuteradio") {
+        MediaPlayer::instance()->play(m_station);
+    }
+    else if (Utils::urlIsPlaylist(m_station->source())) {
+        StreamExtractor::instance()->getStreamUrl(m_station->source());
+    }
+    else {
+        Launcher::launch(m_station->source());
+    }
 }
 
 void StationInfoWindow::toggleFavourite() {
@@ -122,6 +144,16 @@ void StationInfoWindow::onDescriptionChanged(const QString &description) {
     m_descriptionLabel->setText(description.isEmpty() ? tr("No description") : description);
 }
 
+void StationInfoWindow::onLogoChanged(const QUrl &logo) {
+    QImage image(logo.toLocalFile());
+
+    if (image.isNull()) {
+        image = QImage("/usr/share/icons/hicolor/124x124/hildon/mediaplayer_default_stream.png");
+    }
+
+    m_logoLabel->setImage(image.scaled(124, 124, Qt::IgnoreAspectRatio, Qt::SmoothTransformation));
+}
+
 void StationInfoWindow::onGenreChanged(const QString &genre) {
     m_genreLabel->setText(QString("%1: %2").arg(tr("Genre")).arg(genre.isEmpty() ? tr("Unknown") : genre));
 }
@@ -148,4 +180,5 @@ void StationInfoWindow::onFavouriteChanged(bool favourite) {
 
 void StationInfoWindow::onCurrentStationChanged(Station *station) {
     m_playAction->setEnabled((!station) || (station->id() != m_station->id()));
+    m_logoLabel->setEnabled(m_playAction->isEnabled());
 }
