@@ -35,17 +35,30 @@ void StationListDelegate::paint(QPainter *painter, const QStyleOptionViewItem &o
         painter->drawImage(option.rect, QImage("/etc/hildon/theme/images/TouchListBackgroundNormal.png"));
     }
 
+    QRect iconRect = option.rect;
+    iconRect.setSize(QSize(64, 64));
+    iconRect.moveTopLeft(QPoint(iconRect.left() + 8, iconRect.top() + 8));
+
+    QImage logo(index.data(StationListModel::LogoRole).toUrl().toLocalFile());
+
+    if (logo.isNull()) {
+        logo = QImage("/usr/share/icons/hicolor/64x64/hildon/mediaplayer_default_stream.png");
+        painter->drawImage(iconRect, logo);
+    }
+    else {
+        painter->drawImage(iconRect, logo.scaled(64, 64, Qt::IgnoreAspectRatio, Qt::SmoothTransformation));
+    }
+
     bool favourite = index.data(StationListModel::FavouriteRole).toBool();
 
     if (favourite) {
-        QRect iconRect = option.rect;
         iconRect.setSize(QSize(48, 48));
-        iconRect.moveTopRight(QPoint(option.rect.right() - 8, iconRect.top() + 16));
+        iconRect.moveTopRight(QPoint(option.rect.right() - 8, iconRect.top() + 8));
         painter->drawImage(iconRect, QImage("/usr/share/icons/hicolor/48x48/hildon/mediaplayer_internet_radio_favorite.png"));
     }
 
     QRect textRect = option.rect;
-    textRect.moveTopLeft(QPoint(textRect.left() + 8, textRect.top() + 8));
+    textRect.moveTopLeft(QPoint(textRect.left() + 80, textRect.top() + 8));
     textRect.setHeight(32);
     textRect.setRight(textRect.right() - (favourite ? 64 : 8));
 
