@@ -46,6 +46,7 @@ MediaPlayer::MediaPlayer(QObject *parent) :
 
     Phonon::createPath(m_mediaPlayer, m_audioOutput);
 
+    this->connect(m_mediaPlayer, SIGNAL(seekableChanged(bool)), this, SIGNAL(seekableChanged(bool)));
     this->connect(m_mediaPlayer, SIGNAL(tick(qint64)), this, SIGNAL(positionChanged(qint64)));
     this->connect(m_mediaPlayer, SIGNAL(totalTimeChanged(qint64)), this, SIGNAL(durationChanged(qint64)));
     this->connect(m_mediaPlayer, SIGNAL(bufferStatus(int)), this, SLOT(onBufferProgressChanged(int)));
@@ -54,6 +55,7 @@ MediaPlayer::MediaPlayer(QObject *parent) :
     this->connect(m_audioOutput, SIGNAL(volumeChanged(qreal)), this, SIGNAL(volumeChanged(qreal)));
     this->connect(m_extractor, SIGNAL(gotStreamUrl(QUrl)), this, SLOT(play(QUrl)));
     this->connect(m_extractor, SIGNAL(error(QString)), this, SLOT(onExtractorError(QString)));
+    this->connect(Settings::instance(), SIGNAL(mediaPlayerChanged(QString)), this, SLOT(onMediaPlayerChanged(QString)));
 
 #ifdef MEEGO_EDITION_HARMATTAN
     m_resourceSet = new ResourcePolicy::ResourceSet("player", this);
@@ -121,18 +123,16 @@ void MediaPlayer::setState(MediaState::State state) {
 }
 
 QString MediaPlayer::stateString() const {
-    if (this->buffering()) {
-        return tr("Buffering media");
-    }
-
     switch (this->state()) {
-    case Phonon::PlayingState:
+    case MediaState::Buffering:
+        return tr("Buffering");
+    case MediaState::Playing:
         return tr("Playing");
-    case Phonon::PausedState:
+    case MediaState::Paused:
         return tr("Paused");
-    case Phonon::StoppedState:
+    case MediaState::Stopped:
         return tr("Stopped");
-    case Phonon::ErrorState:
+    case MediaState::Error:
         return tr("Error");
     default:
         return tr("Unknown");
@@ -140,13 +140,7 @@ QString MediaPlayer::stateString() const {
 }
 
 bool MediaPlayer::playing() const {
-    switch (this->state()) {
-    case MediaState::Playing:
-    case MediaState::Buffering:
-        return true;
-    default:
-        return false;
-    }
+    return this->state() == MediaState::Playing;
 }
 
 bool MediaPlayer::paused() const {
@@ -157,6 +151,10 @@ bool MediaPlayer::buffering() const {
     return this->state() == MediaState::Buffering;
 }
 
+bool MediaPlayer::seekable() const {
+    return m_mediaPlayer->isSeekable();
+}
+
 QString MediaPlayer::errorString() const {
     return m_errorString;
 }
@@ -265,13 +263,9 @@ void MediaPlayer::play() {
                                           : m_mediaPlayer->currentSource().url());
         return;
     default:
-        break;
+        m_mediaPlayer->play();
+        return;
     }
-#ifdef MEEGO_EDITION_HARMATTAN
-    m_resourceSet->acquire();
-#else
-    m_mediaPlayer->play();
-#endif
 }
 
 void MediaPlayer::play(const QUrl &url) {
@@ -287,7 +281,11 @@ void MediaPlayer::play(const QUrl &url) {
         // url is a local file
         this->setPlaybackMode(PlaybackMode::Sequential);
         m_mediaPlayer->setCurrentSource(url);
-        this->play();
+#ifdef MEEGO_EDITION_HARMATTAN
+        m_resourceSet->acquire();
+#else
+        m_mediaPlayer->play();
+#endif
     }
     else {
         this->setPlaybackMode(PlaybackMode::Radio);
@@ -297,7 +295,11 @@ void MediaPlayer::play(const QUrl &url) {
         }
         else {
             m_mediaPlayer->setCurrentSource(url);
-            this->play();
+#ifdef MEEGO_EDITION_HARMATTAN
+            m_resourceSet->acquire();
+#else
+            m_mediaPlayer->play();
+#endif
         }
     }
 }
@@ -313,6 +315,7 @@ void MediaPlayer::pause() {
 
 void MediaPlayer::stop() {
     m_mediaPlayer->stop();
+    m_extractor->cancelCurrentOperation();
 }
 
 void MediaPlayer::clear() {
@@ -361,6 +364,7 @@ void MediaPlayer::onStateChanged(Phonon::State state) {
         break;
     case Phonon::PausedState:
         this->setState(MediaState::Paused);
+        break;
     case Phonon::StoppedState:
 #ifdef MEEGO_EDITION_HARMATTAN
         m_resourceSet->release();
@@ -389,11 +393,17 @@ void MediaPlayer::onExtractorError(const QString &errorString) {
 }
 
 void MediaPlayer::onStationPlayed() {
-    if (this->currentStation()) {
+    if ((this->currentStation()) && (this->currentStation()->service() == Services::NoService)) {
         Database::asyncUpdateStation(this->currentStation()->id(), "lastPlayed", QDateTime::currentMSecsSinceEpoch(), false);
     }
 }
 
+void MediaPlayer::onMediaPlayerChanged(const QString &mediaPlayer) {
+    if (mediaPlayer != "cuteradio") {
+        this->clear();
+    }
+}
+
 #ifdef MEEGO_EDITION_HARMATTAN
 void MediaPlayer::onResourcesGranted() {
     m_mediaPlayer->play();
@@ -401,6 +411,10 @@ void MediaPlayer::onResourcesGranted() {
 
 void MediaPlayer::onResourcesReleased() {
     qDebug() << "Resources released";
+
+    if (this->playing()) {
+        m_resourceSet->acquire();
+    }
 }
 
 void MediaPlayer::onResourcesDenied() {
