@@ -52,6 +52,9 @@ class MediaPlayer : public QObject
     Q_PROPERTY(bool buffering
                READ buffering
                NOTIFY stateChanged)
+    Q_PROPERTY(bool seekable
+               READ seekable
+               NOTIFY seekableChanged)
     Q_PROPERTY(QString stateString
                READ stateString
                NOTIFY stateChanged)
@@ -113,9 +116,13 @@ public:
     PlaybackMode::Mode playbackMode() const;
 
     bool playing() const;
+
     bool paused() const;
+
     bool buffering() const;
 
+    bool seekable() const;
+
     MediaState::State state() const;
     QString stateString() const;
 
@@ -174,6 +181,7 @@ private slots:
     void onStateChanged(Phonon::State state);
     void onExtractorError(const QString &errorString);
     void onStationPlayed();
+    void onMediaPlayerChanged(const QString &mediaPlayer);
 #ifdef MEEGO_EDITION_HARMATTAN
     void onResourcesGranted();
     void onResourcesReleased();
@@ -184,6 +192,7 @@ private slots:
 signals:
     void currentStationChanged(Station *station);
     void metaDataChanged();
+    void seekableChanged(bool seekable);
     void bufferProgressChanged(int progress);
     void positionChanged(qint64 position);
     void durationChanged(qint64 duration);
