@@ -21,6 +21,7 @@
 #include <QDeclarativeEngine>
 #include <QDeclarativeContext>
 #include <qdeclarative.h>
+#include "launcher.h"
 #include "../base/homescreenmodel.h"
 #include "../base/database.h"
 #include "../base/stationfilterlistmodel.h"
@@ -29,7 +30,17 @@
 #include "../base/selectionmodels.h"
 #include "../base/settings.h"
 #include "../base/utils.h"
+#include "../base/logodownloader.h"
+#include "../base/streamextractor.h"
+#include "../tunein/tuneinhomescreenmodel.h"
+#include "../tunein/tuneinstationfilterlistmodel.h"
+#include "../tunein/tuneinpairlistmodel.h"
+#include "../tunein/tuneinstation.h"
+#ifdef MOBILITY_PLAYER
+#include "../mediaplayer/mobility/mediaplayer.h"
+#else
 #include "../mediaplayer/phonon/mediaplayer.h"
+#endif
 #ifndef Q_WS_SIMULATOR
 #include "volumekeys/mediakeycaptureitem.h"
 #endif
@@ -48,19 +59,29 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     qmlRegisterType<HomescreenModel>("com.cuteradio.models", 1, 0, "HomescreenModel");
     qmlRegisterType<StationFilterListModel>("com.cuteradio.models", 1, 0, "StationListModel");
     qmlRegisterType<PairListModel>("com.cuteradio.models", 1, 0, "PairListModel");
+    qmlRegisterType<TuneInHomescreenModel>("com.cuteradio.models", 1, 0, "TuneInHomescreenModel");
+    qmlRegisterType<TuneInStationFilterListModel>("com.cuteradio.models", 1, 0, "TuneInStationListModel");
+    qmlRegisterType<TuneInPairListModel>("com.cuteradio.models", 1, 0, "TuneInPairListModel");
     qmlRegisterType<ScreenOrientationModel>("com.cuteradio.models", 1, 0, "ScreenOrientationModel");
     qmlRegisterType<LanguageModel>("com.cuteradio.models", 1, 0, "LanguageModel");
+    qmlRegisterType<MediaPlayerModel>("com.cuteradio.models", 1, 0, "MediaPlayerModel");
+    qmlRegisterType<NetworkProxyTypeModel>("com.cuteradio.models", 1, 0, "NetworkProxyTypeModel");
     qmlRegisterType<Station>("com.cuteradio.items", 1, 0, "Station");
+    qmlRegisterType<TuneInStation>("com.cuteradio.items", 1, 0, "TuneInStation");
+    qmlRegisterType<LogoDownloader>("com.cuteradio.items", 1, 0, "LogoDownloader");
 
     qmlRegisterUncreatableType<ScreenOrientation>("com.cuteradio.enums", 1, 0, "ScreenOrientation", "Y U create enum?");
     qmlRegisterUncreatableType<Queries>("com.cuteradio.enums", 1, 0, "Queries", "Y U create enum?");
     qmlRegisterUncreatableType<PlaybackMode>("com.cuteradio.enums", 1, 0, "PlaybackMode", "Y U create enum?");
+    qmlRegisterUncreatableType<MediaState>("com.cuteradio.enums", 1, 0, "MediaState", "Y U create enum?");
 
     Settings settings;
     Database database;
     Utils utils;
+    StreamExtractor extractor;
     MediaPlayer player;
     SearchListModel searchModel;
+    Launcher launcher;
 
     if (!settings.language().isEmpty()) {
         QTranslator translator;
@@ -76,9 +97,12 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     context->setContextProperty("Database", &database);
     context->setContextProperty("MediaPlayer", &player);
     context->setContextProperty("SearchModel", &searchModel);
+    context->setContextProperty("StreamExtractor", &extractor);
+    context->setContextProperty("Launcher", &launcher);
 
 #ifndef Q_WS_SIMULATOR
     MediakeyCaptureItem volumeKeys;
+    volumeKeys.setVolume(player.volume());
     context->setContextProperty("VolumeKeys", &volumeKeys);
     QObject::connect(&volumeKeys, SIGNAL(volumeChanged(int)), &player, SLOT(setVolume(int)));
 #endif
@@ -86,6 +110,7 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     view.data()->setSource(QUrl("qrc:/main.qml"));
     view.data()->showFullScreen();
 
+    QObject::connect(&extractor, SIGNAL(gotStreamUrl(QUrl)), &launcher, SLOT(launch(QUrl)));
     QObject::connect(view.data()->engine(), SIGNAL(quit()), app.data(), SLOT(quit()));
 
     return app.data()->exec();
